=======
Credits
=======

Development Lead
----------------

* Daigo Tanaka <daigo@anelen.co>

Contributors
------------

* @sphinks (Ivan Zerin)
* @NiallRees (Niall Woodward)
* @seanglynn-thrive
* @cjohnhanson (Cody J. Hanson)
* @AlejandroUPC (Alejandro Martínez Otal)
* @gregkoutsimp (Greg Koutsimpogiorgos)
